===============================
Alternatives to django Organice
===============================

With django Organice we strive to make people happy who are not tech or process experts.  People who want to
collaborate smoothly without having taken part of extensive training programmes in order to understand the tool.
Simplicity is key, everything should be intuitive, getting things done easily.  Occasional users should be happy
to the same extent than daily-habit expert users.

But of course, django Organice doesn't fit it all. If you feel it can't satisfy your specific needs it may be
a good idea to look at the following alternatives.  If you happen to know additional offers `drop us a note`_
so we can make the list more complete.

Software Alternatives
=====================

In alphabetical order.

- `Bitrix Intranet`_ (PHP, commercial, ships with source code)
- Coyo_ (Java/Play, commercial, ships with source code)
- `Microsoft SharePoint + Yammer`_ [1]_ (.NET et al., commercial)

Cloud Competitors
=================

In alphabetical order.

- Bitrix24.com_ / Bitrix24.de_ [1]_
- Igloo_


.. _`drop us a note`: info@organice.io
.. _`Bitrix Intranet`: http://www.bitrixsoft.com/products/intranet/
.. _Coyo: https://www.coyoapp.com/
.. _`Microsoft SharePoint + Yammer`: http://office.microsoft.com/sharepoint/

.. _Bitrix24.com: http://bitrix24.com/
.. _Bitrix24.de: http://bitrix24.de/
.. _Igloo: http://www.igloosoftware.com/

.. [1] http://intranetsdoneright.blogspot.com/2013/11/what-is-social-intranet.html
